.. _community:

=====================
Contributor community
=====================

pandas is a community-driven open source project developed by a large group
of `contributors <https://github.com/pandas-dev/pandas/graphs/contributors>`_
and a smaller group of `maintainers <https://pandas.pydata.org/about/team.html>`_.
The pandas leadership has made a strong commitment to creating an open,
inclusive, and positive community. Please read the pandas `Code of Conduct
<https://pandas.pydata.org/community/coc.html>`_ for guidance on how to
interact with others in a way that makes the community thrive.

We offer several meetings and communication channels to share knowledge and
connect with others within the pandas community.

Community meeting
-----------------

The pandas Community Meeting is a regular sync meeting for the project's
maintainers which is open to the community. Everyone is welcome to attend and
contribute to conversations.

The meetings take place on the second and fourth Wednesdays of each month at 18:00 UTC.

The minutes of past meetings are available in `this Google Document <https://docs.google.com/document/d/1tGbTiYORHiSPgVMXawiweGJlBw5dOkVJLY-licoBmBU/edit?usp=sharing>`__.


New contributor meeting
-----------------------

On the third Wednesday of the month, we hold meetings to welcome and support
new contributors in our community.

| 👋 you all are invited
| 💬 everyone can present (add yourself to the hackMD agenda)
| 👀 anyone can sit in and listen

Attendees are new and experienced contributors, as well as a few maintainers.
We aim to answer questions about getting started, or help with work in
progress when possible, as well as get to know each other and share our
learnings and experiences.

The agenda for the next meeting and minutes of past meetings are available in
`this HackMD <https://hackmd.io/@pandas-dev/HJgQt1Tei>`__.

Calendar
--------

This calendar shows all the community meetings. Our community meetings are
ideal for anyone wanting to contribute to pandas, or just curious to know how
current development is going.

.. raw:: html

   <iframe src="https://calendar.google.com/calendar/embed?src=pgbn14p6poja8a1cf2dv2jhrmg%40group.calendar.google.com" style="border: 0" width="800" height="600" frameborder="0" scrolling="no"></iframe>

You can subscribe to this calendar with the following links:

* `iCal <https://calendar.google.com/calendar/ical/pgbn14p6poja8a1cf2dv2jhrmg%40group.calendar.google.com/public/basic.ics>`__
* `Google calendar <https://calendar.google.com/calendar/r?cid=pgbn14p6poja8a1cf2dv2jhrmg@group.calendar.google.com>`__

Additionally, we'll sometimes have one-off meetings on specific topics.
These will be published on the same calendar.

`GitHub issue tracker <https://github.com/pandas-dev/pandas/issues>`_
----------------------------------------------------------------------

The pandas contributor community conducts conversations mainly via this channel.
Any community member can open issues to:

- Report bugs, e.g. "I noticed the behavior of a certain function is
  incorrect"
- Request features, e.g. "I would like this error message to be more readable"
- Request documentation improvements, e.g. "I found this section unclear"
- Ask questions, e.g. "I noticed the behavior of a certain function
  changed between versions. Is this expected?".

    Ideally, your questions should be related to how pandas works rather
    than how you use pandas. `StackOverflow <https://stackoverflow.com/>`_ is
    better suited for answering usage questions, and we ask that all usage
    questions are first asked on StackOverflow. Thank you for respecting our
    time and wishes. 🙇

Maintainers and frequent contributors might also open issues to discuss the
ongoing development of the project. For example:

- Report issues with the CI, GitHub Actions, or the performance of pandas
- Open issues relating to the internals
- Start roadmap discussion aligning on proposals for what to do in future
  releases or changes to the API.
- Open issues relating to the project's website, logo, or governance

The developer mailing list
--------------------------

The pandas mailing list `pandas-dev@python.org <mailto://pandas-dev@python
.org>`_ is used for long form
conversations and to engage people in the wider community who might not
be active on the issue tracker but we would like to include in discussions.

.. _community.slack:

Community slack
---------------

We have a chat platform for contributors, maintainers and potential
contributors. This is not a space for user questions, rather for questions about
contributing to pandas. The slack is a private space, specifically meant for
people who are hesitant to bring up their questions or ideas on a large public
mailing list or GitHub.

If this sounds like the right place for you, you are welcome to join using
`this link <https://join.slack.com/t/pandas-dev-community/shared_invite/zt-1e2qgy1r6-PLCN8UOLEUAYoLdAsaJilw>`_!
Please remember to follow our `Code of Conduct <https://pandas.pydata.org/community/coc.html>`_,
and be aware that our admins are monitoring for irrelevant messages and will remove folks who use
our
slack for spam, advertisements and messages not related to the pandas contributing community. And
please remember that slack is not meant to replace the mailing list or issue tracker - all important
announcements and conversations should still happen there.
